@@ -42,9 +42,9 @@ class Oaxaca:
         """Fit the Oaxaca-Blinder decomposition model.
 
         Args:
-            formula: The formula for the regression model.
-            data: The data containing all variables.
-            group_variable: The name of the column in data that contains the group indicator.
+            formula: R-style formula for the regression model.
+            data:
+            group_variable: The column that contains the group indicator.
 
         Returns:
             The fitted Oaxaca object for method chaining.
@@ -191,11 +191,17 @@ class Oaxaca:
         Args:
             weights: Weights for the non-discriminatory coefficient vector, where keys are
                 the group values and values are the corresponding weights.
-            gu_adjustment: Type of Gardeazabal and Ugidos (2004) adjustment to apply.
-            direction: Direction of the decomposition. Options are:
-                - "group0 - group1": Decompose group0 - group1 (default)
-                - "group1 - group0": Decompose group1 - group0
-                Where group0 is the first group alphabetically and group1 is the second.
+            gu_adjustment: Type of [Gardeazabal and Ugidos (2004)](omitted_base_category_problem.md) adjustment to apply.
+
+                - "none": No adjustment
+                - "unweighted": Apply unweighted GU adjustment
+                - "weighted": Apply weighted GU adjustment
+
+
+            direction: Direction of the decomposition.
+
+                - "group0 - group1"
+                - "group1 - group0"
 
         Returns:
             A new TwoFoldResults object with decomposition results.
@@ -253,15 +259,17 @@ class Oaxaca:
         """Perform three-fold decomposition.
 
         Args:
-            gu_adjustment: Type of Gardeazabal and Ugidos (2004) adjustment to apply:
-                - "none": No adjustment (default)
+            gu_adjustment: Type of [Gardeazabal and Ugidos (2004)](omitted_base_category_problem.md) adjustment to apply.
+
+                - "none": No adjustment
                 - "unweighted": Apply unweighted GU adjustment
                 - "weighted": Apply weighted GU adjustment
-            direction: Direction of the decomposition. Options are:
-                - "group0 - group1": Decompose group0 - group1 (default)
-                - "group1 - group0": Decompose group1 - group0
-                Where group0 is the first group alphabetically and group1 is the second.
 
+
+            direction: Direction of the decomposition.
+
+                - "group0 - group1"
+                - "group1 - group0"
         Returns:
             A new ThreeFoldResults object with decomposition results.
         """
@@ -350,16 +358,18 @@ class Oaxaca:
 
             # Convert to list since pandas can't accept set as index
             dummies_exclusive_to_this_group = list(set(dummies(X_model_spec[this])) - set(dummies(X_model_spec[other])))
-            rows_to_remove = (X[this].loc[:, dummies_exclusive_to_this_group] == 1).any(axis=1)
+            rows_to_remove = (
+                X[this].loc[(X[this].loc[:, dummies_exclusive_to_this_group] == 1).any(axis=1), :].index.tolist()
+            )
 
             # Compute scalar outcomes and share as floats for easier downstream use
             outcome_pre_removal_val = float(y[this].mean().iloc[0])
-            outcome_post_removal_val = float(y[this][~rows_to_remove].mean().iloc[0])
+            outcome_post_removal_val = float(y[this].drop(rows_to_remove).mean().iloc[0])
             # May be NaN if no rows removed; float() preserves NaN
             outcome_among_removed_val = (
-                float(y[this][rows_to_remove].mean().iloc[0]) if len(y[this][rows_to_remove]) > 0 else float("nan")
+                float(y[this].loc[rows_to_remove].mean().iloc[0]) if len(rows_to_remove) > 0 else float("nan")
             )
-            share_removed_val = float(rows_to_remove.mean())
+            share_removed_val = len(rows_to_remove) / len(y[this])
             mean_adjustment_val = outcome_pre_removal_val - outcome_post_removal_val
 
             self.dummy_removal_result_[this] = {
@@ -374,7 +384,7 @@ class Oaxaca:
             # In addition to the full-rank model matrix in OLS below,
             #   calculate the mean of all categories for GU adjustment
             # We do this opportunistically by using the cleaned data
-            cleaned_X = X[this].loc[~rows_to_remove, :].drop(dummies_exclusive_to_this_group, axis=1)
+            cleaned_X = X[this].drop(rows_to_remove).drop(dummies_exclusive_to_this_group, axis=1)
             self.group_stats_all_categories_[this] = {
                 "mean_X": cleaned_X.mean(),
             }
@@ -383,7 +393,9 @@ class Oaxaca:
         for group in self.groups_:
             group_mask = data[self.group_variable] == group
             data_group = data[group_mask]
-            harmonized_data_list.append(data_group.loc[~self.dummy_removal_result_[group]["rows_to_remove"], :])
+            rows_to_remove = self.dummy_removal_result_[group]["rows_to_remove"]
+            # Drop rows by index
+            harmonized_data_list.append(data_group.drop(rows_to_remove, errors="ignore"))
         return pd.concat(harmonized_data_list, axis=0, ignore_index=True)
 
     def _apply_gu_adjustment(self, coef: pd.Series, weight: Optional[pd.Series] = None) -> pd.Series:
